#
# spec file for package openct
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%if 0%{?sles_version} == 10
%define _udevdir /lib/udev
%else
%define _udevdir %(pkg-config --variable=udevdir udev)
%endif
%if "x%{?_udevdir}" == "x"
%if 0%{?sles_version} == 11
%define _udevdir /lib/udev
%endif
%endif

%if "x%{?_udevrulesdir}" == "x"
%if 0%{?sles_version} >= 11
%define _udevrulesdir %{_udevdir}/rules.d
%else
%define _udevrulesdir %{_udevdir}
%endif
%endif

Name:           openct
Version:        0.6.20
Release:        27.5
BuildRequires:  db-devel
BuildRequires:  doxygen
BuildRequires:  krb5-devel
BuildRequires:  libtool
%if 0%{?sles_version} > 10
BuildRequires:  libudev-devel
%endif
BuildRequires:  libusb-devel
BuildRequires:  openldap2-devel
BuildRequires:  pcsc-lite-devel
BuildRequires:  pkg-config
BuildRequires:  udev
PreReq:         %insserv_prereq %fillup_prereq
Url:            http://www.opensc-project.org/openct/
Summary:        Tools for Smart Card Readers
License:        BSD-3-Clause and LGPL-2.1+
Group:          Productivity/Security
ExclusiveArch:  %ix86 x86_64 aarch64
Source:         %{name}-%{version}.tar.bz2
Source2:        README.SUSE
Source3:        baselibs.conf
Source4:        %{name}-rpmlintrc
Source5:        %{name}.service
Source6:        %{name}-handler@.service
Patch1:         %{name}-init.patch
Patch2:         %{name}-udev-permission.patch
Patch3:         %{name}-systemd.patch
Patch4:         %{name}-disable_forcepool.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
# These UID and GID must be equal to values in the pcsc-lite.spec:
%define USER	scard
%define GROUP	scard
# openSUSE package pcsc-lite 1.6.6 is the first one which creates the scard UID and GID:
Requires(post): pcsc-lite >= 1.6.6
%define ifddir %(pkg-config libpcsclite --variable=usbdropdir)
%define LBRACE (
%define RBRACE )
%define QUOTE "
%define BACKSLASH \\
%define USBDRIVERS %(set -x ; bunzip2 <%{S:0} | sed -n 's/^ENV{MODALIAS}==%{QUOTE}%{BACKSLASH}%{LBRACE}usb:[^{QUOTE}]*%{BACKSLASH}%{RBRACE}%{BACKSLASH}*%{QUOTE}.*$/modalias%{LBRACE}%{BACKSLASH}1d*dc*dsc*dp*ic*isc*ip*%{RBRACE}/p' | tr '%{BACKSLASH}n' ' ')
# We are not using Supplements here. User may want to choose between openct and pcsc-lite:
Enhances:       %USBDRIVERS
# Generic CCID devices:
Enhances:       modalias(usb:*ic0Bisc00d*dc*dsc*dp*ic*isc*ip*)
%if 0%{?suse_version} > 1140
BuildRequires:  pkgconfig(systemd)
%{?systemd_requires}
%define has_systemd 1
%endif

%description
OpenCT is a set of library and tools to talk to smart card readers.
OpenCT is used by the OpenSC Smart Card library.

For a list of supported readers, please read documentation in
/usr/share/doc/packages/openct/wiki/index.html - some readers may be
supported only with particular firmware or particular connection type.

There are other packages that may support your reader in a different
way. Name of all these packages starts with "pcsc-".

Authors:
--------
    Olaf Kirch <okir@suse.de>
    Andreas Jellinghaus <aj@dungeon.inka.de>

%package -n libopenct1
Summary:        Library for Smart Card Readers
Group:          System/Libraries

%description -n libopenct1
OpenCT is a set of library and tools to talk to smart card readers.
OpenCT is used by the OpenSC Smart Card library.

For a list of supported readers, please read documentation in
/usr/share/doc/packages/openct/wiki/index.html - some readers may be
supported only with particular firmware or particular connection type.

There are other packages that may support your reader in a different
way. Name of all these packages starts with "pcsc-".

Authors:
--------
    Olaf Kirch <okir@suse.de>
    Andreas Jellinghaus <aj@dungeon.inka.de>

%package -n pcsc-openct
Summary:        PC/SC IFD Handler for OpenCT Smart Card Drivers
Group:          Productivity/Security

%description -n pcsc-openct
PC/SC Connector for OpenCT. It allows to use any of OpenCT Smart Card
drivers with the PCSC-Lite daemon from the pcsc-lite package.

OpenCT is a set of library and tools to talk to smart card readers.
OpenCT is used by the OpenSC Smart Card library.

For a list of supported readers, please read documentation in
/usr/share/doc/packages/openct/wiki/index.html - some readers may be
supported only with particular firmware or particular connection type.

There are other packages that may support your reader in a different
way. Name of all these packages starts with "pcsc-".

Authors:
--------
    Olaf Kirch <okir@suse.de>
    Andreas Jellinghaus <aj@dungeon.inka.de>

%package devel
Summary:        Library for Smart Card Readers
Group:          Development/Libraries/C and C++
Requires:       glibc-devel
Requires:       libopenct1 = %{version}

%description devel
OpenCT is a set of library and tools to talk to smart card readers.
OpenCT is used by the OpenSC Smart Card library.

For a list of supported readers, please read documentation in
/usr/share/doc/packages/openct/wiki/index.html - some readers may be
supported only with particular firmware or particular connection type.

There are other packages that may support your reader in a different
way. Name of all these packages starts with "pcsc-".

Authors:
--------
    Olaf Kirch <okir@suse.de>
    Andreas Jellinghaus <aj@dungeon.inka.de>

%prep

%setup -q -n %{name}-%{version}
cp -a %{S:2} .
%patch1
%patch2 -p1
%if 0%{?has_systemd}
%patch3 -p1
%endif
%patch4 -p1

sed -i 's/@USER@/%{USER}/g;s/@GROUP@/%{GROUP}/g' etc/init-script.in
tr -d \\r <doc/nonpersistent/wiki.out/trac.css >doc/nonpersistent/wiki.out/trac.css.unix
touch -r doc/nonpersistent/wiki.out/trac.css doc/nonpersistent/wiki.out/trac.css.unix
mv doc/nonpersistent/wiki.out/trac.css.unix doc/nonpersistent/wiki.out/trac.css

%build
%if %suse_version > 1110
ACLOCAL="aclocal -I m4" autoreconf -f -i
%endif
%configure\
	--docdir=%{_docdir}/%{name}\
	--disable-static\
	--enable-doc\
	--enable-api-doc\
	--enable-usb\
	--enable-pcsc\
	--enable-non-privileged\
	--with-daemon-user=%{USER}\
	--with-daemon-groups=%{GROUP}\
	--with-bundle=%{ifddir}\
	--with-ifddir=%{ifddir}\
	--with-udev=%{_udevdir}
make %{?jobs:-j%jobs}

%install
mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}
%makeinstall
#

# meanless to create on /run as it is tmpfs
%if 0%{?suse_version} >= 1220
mkdir -p "%{buildroot}/usr/lib/tmpfiles.d/"
cat >%{buildroot}/usr/lib/tmpfiles.d/%{name}.conf <<EOF
d /var/run/%{name} 0755 %{USER} %{GROUP}
EOF
%else
# Create directory
mkdir -p $RPM_BUILD_ROOT%{_localstatedir}/run/openct
# NOTE: Example in the source recommends 750, but this value allows
# access only to dedicated users and root.
chmod 0755 $RPM_BUILD_ROOT%{_localstatedir}/run/openct
%endif

#
# Install init script
mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/init.d
install etc/init-script $RPM_BUILD_ROOT%{_sysconfdir}/init.d/openct
ln -s ../..%{_sysconfdir}/init.d/openct $RPM_BUILD_ROOT%{_sbindir}/rcopenct
# Install 60-openct.rules rule for udev
mkdir -p $RPM_BUILD_ROOT%{_udevrulesdir}
install -m0644 etc/openct.udev $RPM_BUILD_ROOT%{_udevrulesdir}/60-openct.rules
%if 0%{?has_systemd} 
# add systemd services (based on http://blog.fraggod.net/2012/06/16/proper-ish-way-to-start-long-running-systemd-service-on-udev-event-device-hotplug.html)
install -D -m 0644 %{SOURCE5} $RPM_BUILD_ROOT%{_unitdir}/%{name}.service
install -D -m 0644 %{SOURCE6} $RPM_BUILD_ROOT%{_unitdir}/%{name}-handler@.service
rm -f $RPM_BUILD_ROOT%{_udevdir}/openct_*
%endif
#
# Copy the rest of documentation
cp LGPL-2.1 README.SUSE TODO doc/nonpersistent/ChangeLog etc/openct-disable.fdi $RPM_BUILD_ROOT%{_docdir}/%{name}
# And remove pointless .la file
rm $RPM_BUILD_ROOT%{_libdir}/libopenct.la

%pre
%if 0%{?has_systemd}
%service_add_pre %{name}.service
%endif

%preun
%{stop_on_removal openct}
%if 0%{?has_systemd} 
%service_del_preun %{name}.service
%endif

%post
# Remove possible orphans created by openct<=0.6.15 before openct-status-lock-orphans.patch (openSUSE <= 11.1, SLE <= 11):
rm -f %{_localstatedir}/run/openct/status.lock.*
%{fillup_and_insserv -y openct}
%if 0%{?has_systemd}
%service_add_post %{name}.service
%endif
%if 0%{?suse_version} >= 1220
systemd-tmpfiles --create /usr/lib/tmpfiles.d/%{name}.conf
%endif

%postun
%{restart_on_update openct}
%{insserv_cleanup}
%if 0%{?has_systemd}
%service_del_postun %{name}.service
%endif

%post -n libopenct1 -p /sbin/ldconfig

%postun -n libopenct1 -p /sbin/ldconfig

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(-,root,root)
%doc %dir %{_docdir}/%{name}
%doc %{_docdir}/%{name}/ChangeLog
%doc %{_docdir}/%{name}/LGPL-2.1
%doc %{_docdir}/%{name}/NEWS
%doc %{_docdir}/%{name}/README
%doc %{_docdir}/%{name}/README.SUSE
%doc %{_docdir}/%{name}/TODO
%doc %{_docdir}/%{name}/openct-disable.fdi
%doc %{_docdir}/%{name}/wiki
%{_bindir}/*
%if 0%{?suse_version} >= 1220
/usr/lib/tmpfiles.d/openct.conf
%else
%ghost %dir %{_localstatedir}/run/openct
%endif
%doc %{_mandir}/man?/*.*
%{_sbindir}/*
%{_sysconfdir}/init.d/openct
%config(noreplace) %{_sysconfdir}/openct.conf
%{_udevrulesdir}/60-openct.rules
%if 0%{?has_systemd}
%{_unitdir}/%{name}.service
%{_unitdir}/%{name}-handler@.service
%else
%{_udevdir}/openct_*
%endif

%files -n libopenct1
%defattr(-,root,root)
%{_libdir}/*.so.*

%files -n pcsc-openct
%defattr(-,root,root)
%{ifddir}/openct-ifd.bundle

%files devel
%defattr(-,root,root)
%doc %{_docdir}/%{name}/api
%{_includedir}/openct
%{_libdir}/*.so
%{_libdir}/*.*a
%{_libdir}/pkgconfig/libopenct.pc

%changelog
* Tue May 20 2014 ihno@suse.de
- only build this package for x86_64 and aarch64
  (and not for s390x / ppc64le)
* Tue Dec  3 2013 luizluca@tre-sc.gov.br
- Do not overwrite _udevrulesdir macro when defined
- Added libudev-devel in order to get correct udevdir (bnc#859827)
- Fixed udev rules permissions on devices in order to user/group scard be able to use them.
  * Fixes Bug 580144, partial Bug 681680, maybe Bug 544895
- Disabled default force_pool option, as it is not needed in recent kernels
- Added support for systemd. Fixed instability on hotplug
  * Bug 750310 might be closed as it was about sysV init script
- Now, openct is able to list and talk with all supported token tested.
* Thu Apr 25 2013 fcrozat@suse.com
- Move udev rules to /usr/lib/udev for openSUSE 12.3 and later.
* Wed Mar  6 2013 coolo@suse.com
- update license to new format
* Fri Jul 13 2012 rmilasan@suse.com
- Setup correctly the udev rule and scripts for udev.
* Tue Jun 12 2012 mgorse@suse.com
- ensure that /etc exists before running make install
* Sun Nov 20 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Mon Jan 10 2011 sbrabec@suse.cz
- Updated to version 0.6.20:
  * Add support for Rutoken S.
  * Update on udev rules.
- Switched from HAL to udev.
- Dedicated UID and GID are now created by pcsc-lite.
* Tue Dec 15 2009 jengelh@medozas.de
- add baselibs.conf as a source
* Mon Aug 10 2009 sbrabec@suse.cz
- Fixed syntax error in init script (fix from
  Günther J. Niederwimmer).
* Wed Aug  5 2009 sbrabec@suse.cz
- Updated to version 0.6.17:
  * add support for Rutoken ECP (ccid driver)
  * For ccid, etoken* drivers remove polling loop.
  * Fix some issues caused by newer udev version.
  * Handle T1 abort better.
  * Some build system fixes.
  * Some minor fixes.
  * Re-add api documentation (pre-generated).
* Thu Apr  9 2009 sbrabec@suse.cz
- Use dedicated UID/GID to enhance security.
- Start openct by default (bnc#304149#c21).
- Create hardware specific modalias Enhances.
- HAL FDI improved:
  * Use
  * Provide HAL rules for PolicyKit integration.
  * Provide rule for USB CCID readers.
  * Use spec-conforming two stage FDI and documented disabling.
- Fixed production of orphans in /var/run.
- Don't call autoreconf on older products.
* Wed Jan  7 2009 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Thu Oct 30 2008 sbrabec@suse.cz
- Fixed HAL FDI files and hald-addon scripts (bnc#304149).
- Fixed permissions in hald-addon script and /var/run.
- Build a pcsc-openct package.
- "rcopenct stop" does not fail if there is nothing to stop
  (bnc#303829).
* Tue Sep  9 2008 sbrabec@suse.cz
- Updated to version 0.6.15:
  * Build system rewritten.
  * Non privileged configuration added.
  * /etc/openct.conf ifdhandler was modified, please review sample
    before upgrade.
  * Basic coldplug support on Linux is available without libusb
    dependency.
  * CCID-1.10 is now supported.
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Thu Apr  3 2008 sbrabec@suse.cz
- Updated to version 0.6.14:
  * further fixes to udev script
* Tue Apr  1 2008 sbrabec@suse.cz
- FDI rule adapted to new HAL (bnc#372557).
  Patch from Felix Möller.
* Wed Sep 12 2007 sbrabec@suse.cz
- Make hald-addon-openct script executable (#304149).
* Mon Sep 10 2007 sbrabec@suse.cz
- Provide and obsolete pcsc-etoken (#284583).
* Fri Aug 24 2007 sbrabec@suse.cz
- Updated to version 0.6.13 (#304149):
  * hotplugging works correctly
- Fixed sub-package dependencies (#299307).
- Do not hard-depend on syslog for the init script (#299299).
* Wed Jul 25 2007 sbrabec@suse.cz
- Updated to version 0.6.12:
  * add alternative udev rules based on MODALIAS.
  * update wiki export (fix links, add images).
  * make lots of functions static.
  * rename variables clashing with function names such as index.
  * add small delays to smph driver.
  * fix pcsclite compile issue.
  * add ccid as fallback driver if no other is found.
  * add more drivers to etc/ files, get them in sync.
  * fix lots of warnings/issues.
  * add patch for contactless reader support (librfid).
  * add set_params to pcmcia and pcmcia-block code to get
    cm4000/cm4040 drivers to work again.
- Split package according to shared library packaging policy.
* Mon Apr 23 2007 sbrabec@suse.cz
- Updated to version 0.6.11:
  * add usb reset for non-linux too (dummy code only).
  * fix three small bugs/warnings
  * fix etc/Makefile installation
  * bsd compile fixed
  * include string.h in utils.c
  * fix 'BUS="pcmcia"' match in udev rules file.
  * improve egate reset logic
  * implement usb reset
* Mon Oct 23 2006 mjancar@suse.cz
- make /etc/init.d/openct executable (#212507)
- add syslog to Requires (#214298)
* Wed Oct  4 2006 sbrabec@suse.cz
- Do not depend on hal and use multiple ownership of hal
  directories to save bootstrap build time.
* Tue Oct  3 2006 sbrabec@suse.cz
- Updated to version 0.6.9:
  * more work on wbeiuu driver.
  * small delays in egate initialisation for new sealed egate
    token.
  * fix openct.conf for wbeeui driver.
  * move scripts used by udev to /lib/udev/ by default.
  * udev scripts for usb, pcmcia_block and serial readers.
  * add several usb ids to ccid driver config.
  * cleanup the parameters to ifdhandler and openct-control attach.
  * new driver for WB Electronics' Infinity USB Unlimited.
  * new pertosmart ac1038 driver by Carlos Henrique Bauer.
  * new smartkey driver.
  * improved T=1 implementation.
  * improved eutron driver.
  * OPENCT_SOCKETDIR environment can point to any dir for the
    sockets so users can use it without being root.
  * sample reader.conf included for pcsc-lite.
  * add phoenix/smartmouse driver.
  * License is now officialy LGPL.
    Libopenct is still 100%% BSD, in case you want to use it.
  * Siemens B1 driver improved by Lorenz Knauer.
  * bug fixes.
* Fri Jun 16 2006 schwab@suse.de
- Fix syntax error in configure script.
* Fri Mar 24 2006 anicka@suse.cz
- fix uninitialised variable [#159683]
* Mon Feb  6 2006 mjancar@suse.cz
- fix array overflow (#145804)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Jan 20 2006 ro@suse.de
- remove hal from needeforbuild
- add directories to filelist instead
* Wed Jan 11 2006 mjancar@suse.cz
- update to 0.6.6
* Thu Dec 22 2005 kukuk@suse.de
- Add PreReq.
* Tue Nov  8 2005 dmueller@suse.de
- don't build as root
* Fri Aug 26 2005 okir@suse.de
- added hal to neededforbuild, so that autobuild stops complaining
  about /usr/share/hal/* directories not being owned by any package.
  This comment is fifty times the size of the change itself :-)
* Thu Aug 25 2005 okir@suse.de
- Converted hotplug support to HAL (#105276)
* Thu Jul 14 2005 okir@suse.de
- Updated to latest upstream version
* Thu Jan 27 2005 okir@suse.de
- Make the init script provide "openct" (#48840)
* Fri Jan 21 2005 okir@suse.de
- Updated to latest released version (0.6.2)
* Thu Nov 18 2004 ro@suse.de
- use kerberos-devel-packages
* Fri Aug  6 2004 okir@suse.de
- get rid of 64bit warnings
* Thu Aug  5 2004 okir@suse.de
- Updated to latest upstream version (0.5.0)
* Mon Sep 22 2003 okir@suse.de
- Packaged directory /var/run/openct (#31330)
* Wed Sep 10 2003 okir@suse.de
- Made init script LSB compliant
* Sat Aug  2 2003 aj@suse.de
- Make 64-bit clean.
* Thu Jul 31 2003 okir@suse.de
- Initial packaging
